@@ -1,4 +1,3 @@
-import argparse
 import glob
 import hashlib
 import os.path
@@ -6,13 +5,12 @@ import os.path
 import requests
 import semver
 import sentry_sdk
-from clint.textui import puts, colored
 
-from .client import login_to_server, upload_to_server, get_server_version, get_md5_from_file
+from .client import login_to_server, upload, get_server_version, get_md5_from_file, check_token
 from .config import get_config_value, set_config_value
 from .constants import *
 from .exceptions import LoginException, UploadException
-from .helper import input_yn, print_error_tag
+from .helper import input_yn, print_error, print_warning
 from .version import __version__, server_compat_version
 
 ignore_errors = [KeyboardInterrupt]
@@ -23,41 +21,34 @@ sentry_sdk.init(SENTRY_SDK_URL, traces_sample_rate=1.0, release=__version__, ign
 def main():
     print("Welcome to shippy (v.{})!".format(__version__))
 
-    parser = argparse.ArgumentParser(description="Client-side tool for interfacing with shipper.")
-    parser.add_argument('-c', '--chunk-size', action='store_true', help='Edit chunk size')
-    args = parser.parse_args()
-
-    if args.chunk_size:
-        edit_chunk_size()
-        return
-
     # Check for updates
     check_shippy_update()
 
     try:
         server_url = get_config_value("shippy", "server")
         token = get_config_value("shipper", "token")
+
+        token = check_token_validity(server_url, token)
     except KeyError:
-        print(FIRST_TIME_RUN_MSG)
+        print("No configuration file found. You need to configure shippy before you can start using it.")
         server_url = get_server_url()
         token = get_token(server_url)
 
     check_server_compat(server_url)
 
-    chunked_upload = (get_config_value("shippy", "chunked_upload").lower() == "true")
-
     # Search current directory for files
     builds = get_builds_in_current_dir()
 
     if len(builds) == 0:
-        print(NO_MATCHING_FILES_FOUND_ERROR_MSG)
+        print_error(msg="No files matching the submission criteria were detected in the current directory.",
+                    newline=True, exit_after=False)
     else:
         print("Detected {} build(s):".format(len(builds)))
         for build in builds:
             print("\t{}".format(build))
 
         if len(builds) > 1:
-            puts(colored.red("Warning: you seem to be uploading multiple builds. "), newline=False)
+            print_warning("Warning: you seem to be uploading multiple builds. ", newline=False)
             if not input_yn("Are you sure you want to continue?", default=False):
                 return
 
@@ -69,8 +60,10 @@ def main():
 
             if input_yn("Uploading build {}. Start?".format(build)):
                 try:
-                    upload_to_server(build, "{}.md5".format(build), server_url, token,
-                                     use_chunked_upload=chunked_upload)
+                    upload(server_url=server_url,
+                           build_file=build,
+                           checksum_file="{}.md5".format(build),
+                           token=token)
                 except UploadException as exception:
                     print(exception)
 
@@ -79,25 +72,29 @@ def check_server_compat(server_url):
     print("shippy is contacting the remote server... Please wait.")
     server_version = get_server_version(server_url)
     if semver.compare(server_version, server_compat_version) == -1:
-        print("Warning: the server you're connecting to is out-of-date. shippy may not work properly.")
-        print("If you know the server admin, please ask them to upgrade the server.")
-        print(" * Reported server version: \t{}".format(server_version))
-        print(" * Compatible version: \t\t{}".format(server_compat_version))
-        if not input_yn("Are you sure you want to continue? Only proceed if you know what you are doing!",
-                        default=False):
-            exit(0)
+        print_error(msg=SERVER_COMPAT_ERROR_MSG.format(server_version, server_compat_version), newline=True,
+                    exit_after=True)
+        exit(0)
     else:
         print("Finished compatibility check. No problems found.")
 
 
+def check_token_validity(server_url, token):
+    print("Checking if token is valid...")
+    if not check_token(server_url, token):
+        # Token check failed, prompt for login again
+        print("The saved token is invalid. Please sign-in again.")
+        token = get_token(server_url)
+    return token
+
+
 def check_shippy_update():
     print("Checking for updates...")
     r = requests.get("https://api.github.com/repos/ericswpark/shippy/releases/latest")
     latest_version = r.json()['name']
 
     if semver.compare(__version__, latest_version) == -1:
-        print("Warning: shippy is out-of-date. We recommend updating with the following command:")
-        print("\tpip3 install --upgrade shipper-shippy")
+        print(SHIPPY_OUTDATED_MSG.format(__version__, latest_version))
     else:
         print("Finished update check. shippy is up-to-date!")
 
@@ -132,8 +129,7 @@ def check_build(filename):
     md5_hash = md5_hash.hexdigest()
     actual_hash = get_md5_from_file("{}.md5".format(filename))
     if md5_hash != actual_hash:
-        print_error_tag()
-        print("This build's checksum is invalid. ", end='')
+        print_error(msg="This build's checksum is invalid. ", newline=False, exit_after=False)
         return False
     print("MD5 hash of {} matched.".format(filename))
 
@@ -142,15 +138,13 @@ def check_build(filename):
 
     # Check build type
     if build_type != "OFFICIAL":
-        print_error_tag()
-        print("This build is not official. ", end='')
+        print_error(msg="This build is not official. ", newline=False, exit_after=False)
         return False
 
     # Check build variant
     valid_variants = ['gapps', 'vanilla', 'foss', 'goapps']
     if build_variant not in valid_variants:
-        print_error_tag()
-        print("This build has an unknown variant. ", end='')
+        print_error(msg="This build has an unknown variant. ", newline=False, exit_after=False)
         return False
 
     print("Validation of build {} complete. No problems found.".format(filename))
@@ -158,44 +152,43 @@ def check_build(filename):
 
 
 def get_server_url():
-    server_url = input("Enter the server URL: ")
-
-    while True:
-        if "http" not in server_url:
-            print_error_tag()
-            # noinspection HttpUrlsUsage
-            print("Server URL seems to be missing the schema. Please add http:// or https:// to the server URL.")
-        else:
-            break
+    try:
         server_url = input("Enter the server URL: ")
 
-    if server_url[-1] == '/':
-        server_url = server_url[:-1]
+        while True:
+            if "http" not in server_url:
+                # noinspection HttpUrlsUsage
+                print_error(msg="Server URL is missing either http:// or https://.", newline=True, exit_after=False)
+            else:
+                break
+            server_url = input("Enter the server URL: ")
 
-    set_config_value("shippy", "server", server_url)
+        if server_url[-1] == '/':
+            server_url = server_url[:-1]
 
-    return server_url
+        set_config_value("shippy", "server", server_url)
+
+        return server_url
+    except KeyboardInterrupt:
+        exit(0)
 
 
 def get_token(server_url):
     while True:
         from getpass import getpass
 
-        username = input("Enter your username: ")
-        password = getpass(prompt="Enter your password: ")
-
         try:
-            token = login_to_server(username, password, server_url)
-            set_config_value("shipper", "token", token)
-            return token
-        except LoginException:
-            puts(colored.red("An error occurred logging into the server. Please try again."))
+            username = input("Enter your username: ")
+            password = getpass(prompt="Enter your password: ")
 
-
-def edit_chunk_size():
-    print("Now editing the chunk size.")
-    user_size = input("Specify the chunk size in megabytes: ")
-    set_config_value("shippy", "chunked_upload_size", user_size * 1_000_000)
+            try:
+                token = login_to_server(username, password, server_url)
+                set_config_value("shipper", "token", token)
+                return token
+            except LoginException as exception:
+                print_error("{} Please try again.".format(exception), newline=True, exit_after=False)
+        except KeyboardInterrupt:
+            exit(0)
 
 
 if __name__ == "__main__":
